# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_steamguard_global_optspecs
	string join \n u/username= password= a/all m/mafiles-path= p/passkey= v/verbosity= no-update-check http-proxy= proxy-credentials= danger-accept-invalid-certs offline h/help V/version
end

function __fish_steamguard_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_steamguard_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_steamguard_using_subcommand
	set -l cmd (__fish_steamguard_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c steamguard -n "__fish_steamguard_needs_command" -s u -l username -d 'Steam username, case-sensitive.' -r
complete -c steamguard -n "__fish_steamguard_needs_command" -l password -d 'Steam account password. You really shouldn\'t use this if you can avoid it.' -r
complete -c steamguard -n "__fish_steamguard_needs_command" -s m -l mafiles-path -d 'Specify which folder your maFiles are in. This should be a path to a folder that contains manifest.json. Default: ~/.config/steamguard-cli/maFiles' -r
complete -c steamguard -n "__fish_steamguard_needs_command" -s p -l passkey -d 'Specify your encryption passkey.' -r
complete -c steamguard -n "__fish_steamguard_needs_command" -s v -l verbosity -d 'Set the log level. Be warned, trace is capable of printing sensitive data.' -r -f -a "{error\t'',warn\t'',info\t'',debug\t'',trace\t''}"
complete -c steamguard -n "__fish_steamguard_needs_command" -l http-proxy -d 'Use a proxy for HTTP requests.' -r
complete -c steamguard -n "__fish_steamguard_needs_command" -l proxy-credentials -d 'Credentials to use for proxy authentication in the format username:password.' -r
complete -c steamguard -n "__fish_steamguard_needs_command" -s a -l all -d 'Select all accounts in the manifest.'
complete -c steamguard -n "__fish_steamguard_needs_command" -l no-update-check -d 'Disable checking for updates.'
complete -c steamguard -n "__fish_steamguard_needs_command" -l danger-accept-invalid-certs -d 'Accept invalid TLS certificates.'
complete -c steamguard -n "__fish_steamguard_needs_command" -l offline -d 'Assume the computer\'s time is correct. Don\'t ask Steam for the time when generating codes.'
complete -c steamguard -n "__fish_steamguard_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c steamguard -n "__fish_steamguard_needs_command" -s V -l version -d 'Print version'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "approve" -d 'Approve or deny pending login sessions'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "debug" -d 'Debug stuff, not useful for most users.'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "completion" -d 'Generate shell completions'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "setup" -d 'Set up a new account with steamguard-cli'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "import" -d 'Import an account with steamguard already set up. It must not be encrypted. If you haven\'t used steamguard-cli before, you probably don\'t need to use this command.'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "confirm" -d 'Interactive interface for steam mobile confirmations'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "remove" -d 'Remove the authenticator from an account.'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "encrypt" -d 'Encrypt all maFiles'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "decrypt" -d 'Decrypt all maFiles'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "code" -d 'Generate 2FA codes'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "qr" -d 'Generate QR codes. This *will* print sensitive data to stdout.'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "qr-login" -d 'Log in to Steam on another device using the QR code that it\'s displaying.'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "status" -d 'Query and print the 2FA status of an account.'
complete -c steamguard -n "__fish_steamguard_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c steamguard -n "__fish_steamguard_using_subcommand approve" -l auto-approve-ip -d 'Automatically approve all login requests from the given IPv4 addresses non-interactively. Useful for CI/CD systems. Requests that don\'t match will be ignored.' -r
complete -c steamguard -n "__fish_steamguard_using_subcommand approve" -l dangerously-approve-all -d 'Blindly approve all pending login sessions without prompting.'
complete -c steamguard -n "__fish_steamguard_using_subcommand approve" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand debug" -l print-stripped-json -d 'Read the specified file, parse it, strip values, and print the result.' -r
complete -c steamguard -n "__fish_steamguard_using_subcommand debug" -l demo-prompt -d 'Show a text prompt.'
complete -c steamguard -n "__fish_steamguard_using_subcommand debug" -l demo-pause -d 'Show a "press any key" prompt.'
complete -c steamguard -n "__fish_steamguard_using_subcommand debug" -l demo-prompt-char -d 'Show a character prompt.'
complete -c steamguard -n "__fish_steamguard_using_subcommand debug" -l demo-conf-menu -d 'Show an example confirmation menu using dummy data.'
complete -c steamguard -n "__fish_steamguard_using_subcommand debug" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand completion" -s s -l shell -d 'The shell to generate completions for.' -r -f -a "{bash\t'',elvish\t'',fish\t'',powershell\t'',zsh\t''}"
complete -c steamguard -n "__fish_steamguard_using_subcommand completion" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand setup" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand import" -l files -d 'Paths to one or more maFiles, eg. "./gaben.maFile"' -r
complete -c steamguard -n "__fish_steamguard_using_subcommand import" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand confirm" -s a -l accept-all -d 'Accept all open mobile confirmations. Does not open interactive interface.'
complete -c steamguard -n "__fish_steamguard_using_subcommand confirm" -s f -l fail-fast -d 'If submitting a confirmation response fails, exit immediately.'
complete -c steamguard -n "__fish_steamguard_using_subcommand confirm" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand remove" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand encrypt" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand decrypt" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand code" -l offline -d 'Assume the computer\'s time is correct. Don\'t ask Steam for the time when generating codes.'
complete -c steamguard -n "__fish_steamguard_using_subcommand code" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand qr" -l ascii -d 'Force using ASCII chars to generate QR codes. Useful for terminals that don\'t support unicode.'
complete -c steamguard -n "__fish_steamguard_using_subcommand qr" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand qr-login" -l url -d 'The URL that would normally open in the Steam app. This is the URL that the QR code is displaying. It should start with \\"https://s.team/...\\"' -r
complete -c steamguard -n "__fish_steamguard_using_subcommand qr-login" -l image -d 'Path to an image file containing the QR code. The QR code will be scanned from this image' -r -F
complete -c steamguard -n "__fish_steamguard_using_subcommand qr-login" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand status" -l raw -d 'Print raw protobuf response.'
complete -c steamguard -n "__fish_steamguard_using_subcommand status" -s h -l help -d 'Print help'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "approve" -d 'Approve or deny pending login sessions'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "debug" -d 'Debug stuff, not useful for most users.'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "completion" -d 'Generate shell completions'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "setup" -d 'Set up a new account with steamguard-cli'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "import" -d 'Import an account with steamguard already set up. It must not be encrypted. If you haven\'t used steamguard-cli before, you probably don\'t need to use this command.'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "confirm" -d 'Interactive interface for steam mobile confirmations'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "remove" -d 'Remove the authenticator from an account.'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "encrypt" -d 'Encrypt all maFiles'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "decrypt" -d 'Decrypt all maFiles'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "code" -d 'Generate 2FA codes'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "qr" -d 'Generate QR codes. This *will* print sensitive data to stdout.'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "qr-login" -d 'Log in to Steam on another device using the QR code that it\'s displaying.'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "status" -d 'Query and print the 2FA status of an account.'
complete -c steamguard -n "__fish_steamguard_using_subcommand help; and not __fish_seen_subcommand_from approve debug completion setup import confirm remove encrypt decrypt code qr qr-login status help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
